#[derive(Event)]Expand description
Used to implement traits for an aggregate event enum.
Expands to the following:
- Implements
thalo::Apply<...> for thalo::State<T>. - Implements
From<#path> for #identfor each variant.
#[derive(Event)]Used to implement traits for an aggregate event enum.
Expands to the following:
thalo::Apply<...> for thalo::State<T>.From<#path> for #ident for each variant.